@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/installer/RCS/file8.0.tcl,v $
-# $Date: 1997/08/06 09:26:43 $
-# $Revision: 1.18.1.5 $
+# $Source: /home/nlfm/catless/Zircon/installer/RCS/file80.tcl,v $
+# $Date: 1998/09/07 12:01:48 $
+# $Revision: 1.18.1.6 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -19,4 +19,6 @@ proc filerename {from to} {file rename -force $from $to}
 #
 proc copyfile {from to} {file copy -force $from $to}
 #
-proc mkReadable {file} { exec chmod a+r $file }
+proc mkReadable {file} { file attributes $file -permissions 0644 }
+#
+proc mkExecutable {file} { file attributes $file -permissions 0755 }
