@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/installer/RCS/zircon.tcl,v $
-# $Date: 1998/04/29 11:44:40 $
-# $Revision: 1.18.1.13 $
+# $Date: 1998/05/29 13:05:20 $
+# $Revision: 1.18.1.15 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -33,6 +33,9 @@ proc zUnknown {args} {
 	set net [lindex $args 1]
 	if {[$net startup]} {$net fast}
 	if {![auto_load $cmd]} { ircNUM $net $cmd $args } { return [uplevel $args] }
+    } /* {
+        global currentNet
+        return [doircII $currentNet [$currentNet info] $args]
     } default {
 	return [uplevel sys_unknown $args]
     }
@@ -46,6 +49,7 @@ rename Initialise {}
 rename InitGlobals {}
 rename InitLook {}
 rename InitImages {}
+rename InitConsts {}
 #
 if {[set l [llength [set nets [Net :: list]]]] == 1} {
     $defaultNet show
