@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Chat.tcl,v $
-# $Date: 1998/07/23 13:47:59 $
-# $Revision: 1.18.1.44 $
+# $Date: 1998/09/02 12:57:32 $
+# $Revision: 1.18.1.46 $
 #
 package provide zircon 1.18
 #
@@ -130,7 +130,7 @@ proc chat_delete {this} {
     catch {[$this user] deref}
     rename $this {}
     switch {} $cdata(sock) {} default {closeChat $this $chan $cdata(sock)}
-    unset CHTO($chan) cdata
+    safeUnset [list CHTO${net}($chan)] $this
     $net deregister chats $this
     if {[winfo exists .@dls$net]} { buildDCCList $net }
 }
