@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Control.tcl,v $
-# $Date: 1998/07/14 15:42:19 $
-# $Revision: 1.18.1.101 $
+# $Date: 1998/08/24 08:44:30 $
+# $Revision: 1.18.1.102 $
 #
 #
 package provide zircon 1.18
@@ -592,7 +592,14 @@ proc netspaceMenu {w} {
     if {![file exists [set ns [file join $zircon(prefdir) netspaces]]]} {
 	$w.spaces configure -state disabled
     } {
+	set cnt 0
 	foreach x [lsort [glob -nocomplain [file join $ns *]]] {
+	    if {[incr cnt] >= 20} {
+		set cnt 0
+		$om add cascade -label [trans more] \
+		  -menu [set m [menu $om.more -tearoff 0]]
+		set om $m
+	    }
 	    addNS $om $x
 	}
 	$om add separator
