@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Help.tcl,v $
-# $Date: 1998/03/20 14:39:04 $
-# $Revision: 1.18.1.9 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Help.tcl,v $
+# $Date: 1998/07/10 13:33:50 $
+# $Revision: 1.18.1.10 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -38,11 +38,8 @@ proc makeHelp {win nm} {
 #
 proc zHelpWind {ctl file title} {
     if {[winfo exists $ctl]} { popup $ctl ; return }
-    toplevel $ctl -class Zircon -borderwidth 2
+    makeToplevel $ctl $title {} {}
     set oFrm $ctl
-    wm title $ctl $title
-    wm resizable $ctl 1 1
-    wm protocol $ctl WM_DELETE_WINDOW "destroy $ctl"
     grid columnconfigure $ctl 0 -weight 1
     grid rowconfigure $ctl 0 -weight 1
     scrollbar $ctl.vs -command "$ctl.txt yview"
