@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Log.tcl,v $
-# $Date: 1998/04/23 08:59:06 $
-# $Revision: 1.18.1.17 $
+# $Source: /home/nlfm/catless/Zircon/lib/RCS/Log.tcl,v $
+# $Date: 1998/05/21 12:55:26 $
+# $Revision: 1.18.1.18 $
 #
 package provide zircon 1.18
 #
@@ -44,6 +44,7 @@ proc logOpen {this mode save fl} {
 	puts $cdata(logfd) "[[$this text] get 1.0 end]"
 	puts $cdata(logfd) "**** End of Window Text"
     }
+    $this showFlags log on
     return 1
 }
 #
@@ -67,6 +68,7 @@ proc channel_doLog {this op} {
 		$w entryconfigure 2 -state disabled
 		$w entryconfigure 3 -state disabled
 	    }
+	    $this showFlags log {}
 	}
     Empty {
 	    switch {} $cdata(logfd) {} default {
