@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Mac.tcl,v $
-# $Date: 1997/04/07 12:01:38 $
-# $Revision: 1.18.1.6 $
+# $Date: 1998/02/09 16:56:41 $
+# $Revision: 1.18.1.7 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -14,10 +14,10 @@ package provide macintosh 1.18
 #
 proc tmpdir {} {
     global env zircon
-    if [info exists zircon(tmp)] { return $zircon(tmp) }
-    if [info exists env(TEMP)] { return $env(TEMP) }
+    if {[info exists zircon(tmp)]} { return $zircon(tmp) }
+    if {[info exists env(TEMP)]} { return $env(TEMP) }
     set fl [file join $env(PREF_FOLDER) Zircon temp]
-    if ![file exists $fl] { file mkdir $fl }
+    if {![file exists $fl]} { file mkdir $fl }
     return $fl
 }
 #
