@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Message.tcl,v $
-# $Date: 1998/04/28 13:15:26 $
-# $Revision: 1.18.1.37 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Message.tcl,v $
+# $Date: 1998/07/23 13:48:02 $
+# $Revision: 1.18.1.38 $
 #
 package provide zircon 1.18
 #
@@ -136,8 +136,7 @@ proc Message_save {desc net} {
 }
 #
 proc message_save {this desc} {
-    global defMsg
-    mncSave $desc $this defMsg
+    mncSave $desc $this defMsg Message
     foreach  b [$this bindings] {
 	puts $desc "zbind [$this name] [lindex $b 0] {[lindex $b 1]}"
     }
