@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Net.tcl,v $
-# $Date: 1998/08/18 11:16:11 $
-# $Revision: 1.18.1.153 $
+# $Date: 1998/09/23 11:29:56 $
+# $Revision: 1.18.1.154 $
 #
 package provide zircon 1.18
 #
@@ -838,13 +838,21 @@ proc net_delete {this} {
     [$this info] delete
     [$this listid] delete
     catch {deleteFrame .@dbgctl $this}
+    $this removeAfters
+    safeUnset [list XTO([string tolower [$this name]])] OType($this) \
+      $this Split$net Heal$net TSplit$net
     global znetList
-    safeUnset [list XTO([string tolower [$this name]])] OType($this) $this
     listkill znetList $this
     remShareLook $this
     rename $this {}
 }
 #
+proc net_removeAfters {this} {
+    upvar #0 TSplit$net TSplit Heal$net Heal
+    foreach {x y} [array get TSplit] { after cancel $y }
+    foreach {x y} [array get Heal] { after cancel $y }
+}
+#
 proc net_squery {this} {
     mkEntryBox {} Squery {Enter your query} \
       [list [list service {}] [list query {}]] \
