@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Notrace.tcl,v $
-# $Date: 1998/04/29 11:44:28 $
-# $Revision: 1.18.1.26 $
+# $Date: 1998/04/30 13:17:47 $
+# $Revision: 1.18.1.27 $
 #
 #
 package provide Notrace 1.18
@@ -34,7 +34,7 @@ proc ircInput {mode conn} {
 	switch -glob $prefix {
 	:* { }
 	PING {
-		$net qSend PONG :[string range $cmd 1 end]
+		$net q1Send "PONG :[string range $cmd 1 end]"
 		return
 	    }
 	ERROR {
@@ -82,8 +82,9 @@ proc net_qSend {this op args} {
 #
 proc net_sendRaw {this value} {
     upvar #0 ${this}(sock) sock
-    switch {} $sock return
-    if {[catch {puts $sock $value} msg]} {$this close $msg ; return 1}
+    switch {} $sock {} default {
+        if {[catch {puts $sock $value} msg]} {$this close $msg ; return 1}
+    }
     return 0
 }
 #
