@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Sound.tcl,v $
-# $Date: 1998/08/19 12:44:13 $
-# $Revision: 1.18.1.16 $
+# $Date: 1998/08/24 08:44:34 $
+# $Revision: 1.18.1.17 $
 #
 package provide zircon 1.18
 #
@@ -79,10 +79,10 @@ proc buildSMenu {net menu chid} {
 	}
 	set cnt 0
 	foreach x [lsort $fls] {
-            if {[incr cnt] > 20} {
-	        set cnt 1
-	        set m [menu $menu.more -tearoff 0]
-	        $menu add cascade -label [trans more] -menu $m
+            if {[incr cnt] >= 20} {
+	        set cnt 0
+	        $menu add cascade -label [trans more] \
+		  -menu [set m [menu $menu.more -tearoff 0]]
 	        set menu $m
 	    }
 	    $menu add command -label [file tail [file rootname $x]] \
