@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Topic.tcl,v $
-# $Date: 1997/05/16 09:41:54 $
-# $Revision: 1.18.1.5 $
+# $Date: 1998/02/09 16:56:52 $
+# $Revision: 1.18.1.7 $
 #
 package provide zircon 1.18
 #
@@ -19,7 +19,7 @@ proc keepTopic {this value} {
 	[$this window].topic.label.menu add command \
 	  -label "[prune $value 15]" \
 	  -command "$this configure -topic {$value}"
-	if [$this keep] { [$this net] configure -confChange 1 }	
+	if {[$this keep]} { [$this net] configure +confChange Channels }	
     }
 }
 #
@@ -31,7 +31,7 @@ proc getTopic {this} {
 }
 #
 proc sendTopic {this win} {
-    if [normal $win] {$this configure -topic [$win get 1.0 end]}
+    if {[normal $win]} {$this configure -topic [$win get 1.0 end]}
 }
 #
 proc irc331 {net prefix param pargs} {
