@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Tracing.tcl,v $
-# $Date: 1998/04/30 13:17:49 $
-# $Revision: 1.18.1.31 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Tracing.tcl,v $
+# $Date: 1998/09/02 12:57:35 $
+# $Revision: 1.18.1.32 $
 #
 #
 package provide Tracing 1.18
@@ -246,8 +246,8 @@ proc acceptChat {usr newc hst args} {
     set chdata(obj) $cht
     fconfigure $newc -buffering none -blocking 0 -translation {auto lf}
     fileevent $newc readable "dccChat r $newc"
-    catch {close $AChat($usr)}
-    catch {unset AChat($usr)}
+    if {[catch {close $AChat($usr)} msg]} { zIn "Error : $msg" }
+    if {[catch {unset AChat($usr)} msg]} { zIn "error : $msg" }
     if {[winfo exists .@dls$net]} { buildDCCList $net }
     zIn "Chat Accept : [$usr name] on $hst" [$usr net]
 }
