@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/Util.tcl,v $
-# $Date: 1998/08/19 12:17:36 $
-# $Revision: 1.18.1.75 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Util.tcl,v $
+# $Date: 1998/09/24 08:16:58 $
+# $Revision: 1.18.1.78 $
 #
 package provide zircon 1.18
 #
@@ -293,8 +293,6 @@ proc addSeparator {w args} {
 #
 proc getDate {} { return [clock format [clock seconds]] }
 #
-proc convTime {t} { return [clock format $t] }
-#
 proc ipPack {ip} {
     set val 0
     foreach x [split $ip .] { set val [expr {($val << 8) | ($x & 0377)}] }
@@ -595,24 +593,30 @@ proc fixList {lst} {
 }
 #
 proc uExpand {w net chid} {
-    global hits pick zircon
+    global pick zircon
     set txt [$w get]
     set end [$w index insert]
     set start [string wordstart $txt $end]
-    set hd [string tolower [string range $txt $start $end]]
-    set hits($w) {}
-    foreach u [$chid users] {
-	if {[string match $hd* [$u lname]]} {lappend hits($w) $u}
+    switch {} [set hd [string tolower [string range $txt $start $end]]] {
+        return {}
     }
-    switch {} $hits($w) { unset hits($w) ; return {} }
-    if {[llength $hits($w)] > 1} {
+    set hits {}
+    foreach u [$chid users] {
+	if {[string match $hd* [$u lname]]} {lappend hits $u}
+    }
+    switch {} $hits { return {} }
+    if {[llength $hits] > 1} {
 	set m [menu .@[newName Exp] -tearoff 0]
 	set f 0
-	foreach u $hits($w) {
+	foreach u $hits {
 	    set cmd "set pick($w) $u ; destroy $m"
-	    $m add command -label [$u name] -accelerator F[incr f] \
+	    incr f
+	    if {[catch {bind $m <F$f> $cmd}]} {
+	        $m add command -label [$u name] -command $cmd
+	    } {
+	      $m add command -label [$u name] -accelerator F$f \
 	      -command $cmd
-	    bind $m <F$f> $cmd
+	    }
 	}
 	set xy [$w bbox insert]
 	set x [expr {[lindex $xy 0] + [winfo rootx $w]}]
@@ -624,9 +628,8 @@ proc uExpand {w net chid} {
 	set res $pick($w)
 	unset pick($w)
     } {
-	set res $hits($w)
+	set res $hits
     }
-    unset hits($w)
     return [string range [$res name] [string length $hd] end]
 }
 #
