@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/confChan.tcl,v $
-# $Date: 1998/06/07 19:13:09 $
-# $Revision: 1.18.1.31 $
+# $Source: /home/nlfm/Zircon/lib/RCS/confChan.tcl,v $
+# $Date: 1998/07/12 16:17:47 $
+# $Revision: 1.18.1.32 $
 #
 package provide zircon 1.18
 #
@@ -168,8 +168,8 @@ proc confChannels {net win} {
     set j 0
     foreach opt [array names Configure.Channel] {
 	switch [lindex [set ov [set Configure.Channel($opt)]] 0] bool {
-	    switch {} [set tn [lindex $ov 1]] { set tn [trans $opt] }
-	    checkbutton $win.options.$opt -text $tn \
+	    switch {} [set tn [lindex $ov 1]] { set tn $opt }
+	    checkbutton $win.options.$opt -text [trans $tn] \
 	      -variable new$defChan($net)($opt) \
 	      -command "confDirty $net"
 	    grid $win.options.$opt -row $i -column $j -sticky w
