@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/confTab.tcl,v $
-# $Date: 1998/06/07 19:21:26 $
-# $Revision: 1.18.1.16 $
+# $Source: /home/nlfm/Zircon/lib/RCS/confTab.tcl,v $
+# $Date: 1998/07/10 13:33:57 $
+# $Revision: 1.18.1.17 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -20,8 +20,7 @@ proc configWin {net} {
 	return
     }
     set lastConf($net) Nicknames
-    toplevel $w -class Zircon
-    wm title $w "Configure Netspace [$net name]"
+    makeToplevel $w "Configure Netspace [$net name]" {} {}
     frame $w.btn
     foreach x {revert apply save dismiss} {
 	button $w.btn.$x -text [trans $x] -command "conf$x $net $w.f.chld"
