@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/config.tcl,v $
-# $Date: 1998/06/25 09:32:33 $
-# $Revision: 1.18.1.32 $
+# $Date: 1998/07/01 09:34:48 $
+# $Revision: 1.18.1.33 $
 #
 package provide zircon 1.18
 #
@@ -96,7 +96,7 @@ proc confCopyBack {net which} {
 	    confDirty $net
 	}
     }
-    unset newd
+    catch {unset newd}
     foreach x [$net confChange] {
 	switch $which {
 	Friends { $net setupUsers }
