@@ -1,7 +1,7 @@
 
 # $Source: /home/nlfm/Zircon/lib/RCS/ctcp.tcl,v $
-# $Date: 1998/07/16 11:11:19 $
-# $Revision: 1.18.1.35 $
+# $Date: 1998/08/19 12:17:38 $
+# $Revision: 1.18.1.36 $
 #
 package provide zircon 1.18
 #
@@ -38,10 +38,10 @@ proc handleCTCP {net op chid chan usr prefix ign param} {
     switch -exact -- $op {
     CLIENTINFO {
 	    set ctcps {CLIENTINFO VERSION USERINFO ACTION TIME DCC SED ZIRCON}
-	    switch {} [$net wavplayer] {} default {lappend ctcps SOUND}
+	    switch {} [$net players] {} default {lappend ctcps SOUND}
     	    switch {} $param {
 	        set ctcps {CLIENTINFO VERSION USERINFO ACTION TIME DCC SED ZIRCON}
-	        switch {} [$net wavplayer] {} default {lappend ctcps SOUND}
+	        switch {} [$net players] {} default {lappend ctcps SOUND}
 	        ctcpReply $net $chan $nk $op "$ctcps: The Zircon IRC client"
 	    } default {
 	    	set v No
