@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/dbgsrv.tcl,v $
-# $Date: 1998/05/07 11:01:29 $
-# $Revision: 1.18.1.10 $
+# $Source: /home/nlfm/Zircon/lib/RCS/dbgsrv.tcl,v $
+# $Date: 1998/07/10 13:36:03 $
+# $Revision: 1.18.1.12 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -15,9 +15,7 @@ proc DebugServer {w} {
     global zircsrv zircon
     if {[catch {socket -server acceptIRC 6667} zircsrv]} { return 0 }
     $w configure -state disabled
-    set ctl [toplevel .@dbgsrv -class Zircon]
-    wm title $ctl "Zircon Dummy Server"
-    wm resizable $ctl 1 1
+    set ctl [makeToplevel .@dbgsrv "Zircon Dummy Server" "DSClose $w $ctl" {}]
     set f [frame $ctl.btn]
     button $f.stop -text Stop -command "DSClose $w $ctl" -width 8
     button $f.close -text Close -width 8 -command {
@@ -31,13 +29,11 @@ proc DebugServer {w} {
     grid $f -sticky ew
     grid [frame $ctl.l1 -background $zircon(sepColor) -borderwidth 2] -sticky ew -pady 4
     grid [set f [frame $ctl.resp]] -sticky ew
-    grid [menubutton $f.cnct -text Connect -menu $f.cnct.menu -state
-disabled] -sticky ew
+    grid [menubutton $f.cnct -text Connect -menu $f.cnct.menu -state disabled] -sticky ew
     set m [menu $f.cnct.menu]
     $m add command -label Accept -command "DSAccept $ctl.txt"
     $m add command -label Unavailable -command "DSUnavailable $ctl.txt ztest"
-    grid [button $f.quit -text Quit -command "QuitEm $ctl.txt #ztest
-ztest" -state disabled] -row 0 -column 1 -sticky ew
+    grid [button $f.quit -text Quit -command "QuitEm $ctl.txt #ztest ztest" -state disabled] -row 0 -column 1 -sticky ew
     grid [menubutton $f.join -text Join -menu $f.join.menu -state disabled] -row 0 -column 2 -sticky ew
     set m [menu $f.join.menu]
     $m add command -label Join -command "DSJoin1 $ctl.txt #ztest ztest"
