@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/debug.tcl,v $
-# $Date: 1998/07/15 13:39:37 $
-# $Revision: 1.18.1.37 $
+# $Date: 1998/07/21 13:15:27 $
+# $Revision: 1.18.1.39 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -31,10 +31,10 @@ proc zWClear {txt} {
     $txt configure -state disabled
 }
 #
-proc zDbgHist {inc ent} {
+proc zDbgHist {inc txt ent} {
     global DBGPos
     $ent delete 0 end
-    set rng [.@dbgctl.dbg.bdy.txt tag ranges input]
+    set rng [$txt tag ranges input]
     set foo [lindex $rng $DBGPos]
     switch end $DBGPos {
 	switch {} $foo return
@@ -44,7 +44,7 @@ proc zDbgHist {inc ent} {
     if {$DBGPos <= 0} { set DBGPos end }
     if {$DBGPos >= [llength $rng]} { set DBGPos 1 }
     set idx [lindex [split $foo .] 0]
-    $ent insert insert [.@dbgctl.dbg.bdy.txt get $idx.2 "$idx.0 lineend"]
+    $ent insert insert [$txt get $idx.2 "$idx.0 lineend"]
 }
 #
 proc zDbgDo {} {
@@ -242,7 +242,8 @@ proc zDBGControl {} {
       -command "zDump [file join [tmpdir] zircon.dump]"
     button $f.kill -text [trans kill] -width 8 -command  zKill
     button $f.srv -text [trans server] -width 8 -command "DebugServer $f.srv"
-    grid $f.close $f.dump $f.kill $f.srv -sticky ew
+    button $f.rdb -text [trans remote] -width 8 -command RDBG
+    grid $f.close $f.dump $f.kill $f.srv $f.rdb -sticky ew
     grid $f -sticky ew
     zDBGCsw $ctl dbg {Command Interpreter} 0 1
     if {[llength [set nets [Net :: list]]] == 1} {
@@ -256,6 +257,39 @@ proc zDBGControl {} {
     catch {wm geometry $ctl $zlayout(default,debug)}
 }
 #
+proc RDBG {} {
+    mkEntryBox .@rdb {Remote Exec} {Enter user and netspace:} \
+      [list [list user {}] [list netspace {}]] \
+      [list ok doRDBG] [list cancel {}]
+}
+#
+proc doRDBG {usr net} {
+    foreach x [Net :: list] {
+        switch -- [$x name] $net {
+	   switch nil [set r [User :: find $usr $x]] return
+	   zDBGRemote $x $r
+	   return
+	}
+    }
+}
+#
+proc zDBGRemote {net usr} {
+    global zscr zircon zlayout rdbg
+    if {![winfo exists [set ctl .@dbgrem]]} {
+        makeToplevel $ctl "Zircon Remote Debugger" \
+          {catch {uplevel #0 unset zscr}} {}
+        grid columnconfigure $ctl 0 -weight 1 -minsize 100
+        set f [frame $ctl.btn]
+        button $f.close -text [trans dismiss] \
+	  -command "destroy $ctl ; catch {unset rdbg}" -width 8
+        grid $f.close -sticky ew
+        grid $f -sticky ew
+    }
+    if {[winfo exists $ctl.$net$usr]} { raise $ctl ; return }
+    set rdbg($net$usr) [list $net $usr]
+    zDBGCsw $ctl $net$usr "[$usr name] on [$net name]" 0 2
+}
+#
 proc zWLog {net btn} {
     global DBGL
     if {[info exists DBGL($net)]} {
@@ -278,38 +312,51 @@ proc zDBRegion {f tr net ent} {
     grid [frame $f.f3 -borderwidth 0] -column 2 -rowspan 2 -row 0 -sticky ns
     zDBGText $f $net
     if {$tr} {
+	uplevel #0 set DBStamp($net) 0
 	set x Show
 	if {[$net monitorIn]} { set x Hide }
-	button $f.f3.tracein -text "$x In" -width 8 \
-	  -command "zDBIn $net" -foreground red
+	grid [button $f.f3.tracein -text "$x In" -width 8 \
+	  -command "zDBIn $net" -foreground red]
 	set x Show
 	if {[$net monitorOut]} { set x Hide }
-	button $f.f3.traceout -text "$x Out" -width 8 \
-	  -command "zDBOut $net" -foreground blue
-	button $f.f3.tstamp -text "Timestamp" -width 8 -command "zDBStamp $net"
-	uplevel #0 set DBStamp($net) 0
-	grid $f.f3.tracein
-	grid $f.f3.traceout
-	grid $f.f3.tstamp
+	grid [button $f.f3.traceout -text "$x Out" -width 8 \
+	  -command "zDBOut $net" -foreground blue]
+	grid [button $f.f3.tstamp -text "Timestamp" -width 8 -command "zDBStamp $net"]
     }
-    button $f.f3.save -text [trans save] -width 8 -command "zDCSave $net $f.txt"
-    button $f.f3.log -text [trans log] -width 8 -command "zWLog $net $f.f3.log"
-    button $f.f3.clear -text [trans clear] -width 8 -command "zWClear $f.txt"
-    grid $f.f3.save
-    grid $f.f3.log
-    grid $f.f3.clear
-    if {$ent} {
-	emacsEntry $f.entry -relief sunken
-	grid $f.entry -row 2 -columnspan 3 -column 0 -sticky ew
+    grid [button $f.f3.save -text [trans save] -width 8 -command "zDCSave $net $f.txt"]
+    grid [button $f.f3.log -text [trans log] -width 8 -command "zWLog $net $f.f3.log"]
+    grid [button $f.f3.clear -text [trans clear] -width 8 -command "zWClear $f.txt"]
+    if {!$ent} return
+    emacsEntry $f.entry -relief sunken
+    grid $f.entry -row 2 -columnspan 3 -column 0 -sticky ew
+    bind $f.entry <Return> zDbgDo
+    bind $f.entry <Control-p> "zDbgHist 2 $f.txt %W"
+    bind $f.entry <Up> [bind $f.entry <Control-p>]
+    bind $f.entry <Control-n> "zDbgHist -2 $f.txt %W"
+    bind $f.entry <Down> [bind $f.entry <Control-n>]
+    bind $f <Enter> "focus $f.entry"
+   switch $ent 1 {
 	bind $f.entry <Return> zDbgDo
-	bind $f.entry <Control-p> "zDbgHist 2 %W"
-	bind $f.entry <Up> [bind $f.entry <Control-p>]
-	bind $f.entry <Control-n> "zDbgHist -2 %W"
-	bind $f.entry <Down> [bind $f.entry <Control-n>]
-	bind $f <Enter> "focus $f.entry"
+    } 2 {
+	bind $f.entry <Return> "zDbgRx $net"
     }
 }
 #
+proc zDbgRx {dbg} {
+    global DBGPos zscr errorInfo rdbg
+    set w .@dbgrem.$dbg.bdy
+    set cmd [$w.entry get]
+    foreach {net usr} [set rdbg($dbg)] break
+    $net CTCP ZIRCON [$usr name] "EVAL $cmd"
+    $w.txt configure -state normal
+    $w.txt insert end {% }
+    $w.txt insert end $cmd input
+    $w.txt insert end "\n"
+    $w.txt configure -state disabled
+    if {$zscr($dbg)} { $w.txt see end }
+    $w.entry delete 0 end
+}
+#
 proc zDBGText {f net} {
     global zLock
     grid columnconfigure $f 0 -weight 1
