@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/initial.tcl,v $
-# $Date: 1998/08/19 12:17:40 $
-# $Revision: 1.18.1.174 $
+# $Date: 1998/09/23 11:30:01 $
+# $Revision: 1.18.1.177 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -82,6 +82,9 @@ proc zbind {a1 a2 args} {
 	set sequence $a2
 	set action [lindex $args 0]
     }
+    if {![regexp {^<.*>$} $sequence]} {
+        set sequence <$sequence>
+    }
     switch {} $chan {
 	$currentNet configure +bindings [list $sequence $action]
     } default {
@@ -440,7 +443,7 @@ proc InitGlobals {} {
 #
 # Array variables
 #
-    makeArray TFg TBg TAF TAB TSplit Heal Split MkOp Host Shost Share
+    makeArray TFg TBg TAF TAB MkOp Host Shost Share
 #
     set user [username]
 #
@@ -636,11 +639,11 @@ proc checkMainClose {} {
     global zWClose zWInc zWList
     set val 0
     foreach x $zWList {
-        if {[$x closetime] != 0} {
-	    if {$val == 0 || [$x closetime] < $val} {
-	        set val [$x closetime]
+        catch {if {[set ct [$x closetime]] != 0} {
+	    if {$val == 0 || $ct < $val} {
+	        set val $ct
 	    }
-	}
+	}}
     }
     if {$val <= 0} {
         set zWInc 30000
