@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/main.tcl,v $
-# $Date: 1998/05/21 12:55:34 $
-# $Revision: 1.18.1.86 $
+# $Source: /home/nlfm/Zircon/lib/RCS/main.tcl,v $
+# $Date: 1998/07/14 09:32:25 $
+# $Revision: 1.18.1.87 $
 #
 package provide zircon 1.18
 #
@@ -83,7 +83,7 @@ proc channelMode {net chan} {
 #
 proc channelWho {net chan} {
     switch {} $chan return
-    $net q1Send "WHO :$chan"
+    $net WHO $chan
 }
 #
 proc channelNames {net chan} {
@@ -244,7 +244,7 @@ proc irc303 {net prefix param pargs} {
 	}
 	eval $cmd
     }
-    foreach x $signInfo($net) {$net q1Send "USERHOST :[$x name]"}
+    foreach x $signInfo($net) {$net sysQ "USERHOST :[$x name]"}
     foreach x $signons { handleOn $net ISON $x }
 }
 #
