@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/misc.tcl,v $
-# $Date: 1998/05/22 12:53:22 $
-# $Revision: 1.18.1.45 $
+# $Source: /home/nlfm/Zircon/lib/RCS/misc.tcl,v $
+# $Date: 1998/07/14 09:32:27 $
+# $Revision: 1.18.1.48 $
 #
 package provide zircon 1.18
 #
@@ -15,7 +15,7 @@ proc credits {} {
     set w [winfo screenwidth .]
     set iw [image width advert]
     set ih [image height advert]
-    toplevel .@abt
+    makeToplevel .@abt {} {} {}
     wm overrideredirect .@abt 1
     wm resizable .@abt 0 0
     grid [frame .@abt.f -borderwidth 4 -relief raised -bg white]
@@ -206,12 +206,10 @@ proc irc302 {net prefix param pargs} {
 	if {![catch {connect $host 79} sock]} {
 		set w .@[newName fng]
 		fileevent $sock readable "handleFinger $net $sock $w"
-		toplevel $w -class Zircon
-		wm title $w "Finger [$usr name]"
-		wm protocol $w WM_DELETE_WINDOW "
+		makeToplevel $w "Finger [$usr name]" "
 		    destroy $w
 		    catch {close $sock}
-		"
+		" {}
 		grid columnconfigure $w 0 -weight 1
 		grid rowconfigure $w 0 -weight 1
 		scrollbar $w.vscroller -command "$w.text yview"
@@ -313,8 +311,7 @@ proc irc318 {net prefix param pargs} {
     }
     set w .@[newName whos]
     catch {destroy $w}
-    toplevel $w -class Zircon
-    wm title $w "WHOIS $who"
+    makeToplevel $w "WHOIS $who" {} {}
     grid [text $w.t -relief raised -height 5 -width $wd] -sticky nsew
     grid columnconfigure $w 0 -weight 1
     grid rowconfigure $w 0 -weight 1
@@ -380,32 +377,37 @@ proc irc342 {net prefix param pargs} {
 #
 proc irc315 {net prefix param pargs} {
     global whoTxt
-    if {[info exists whoTxt($net)]} {
-	if {[string match {.@who*} $whoTxt($net)] && \
-	  [winfo exists $whoTxt($net)]} {$whoTxt($net) yview 0}
-	unset whoTxt($net)
+    upvar #0 $net ndata whoTxt($net) tv
+    set ndata(whohandler) [lrange $ndata(whohandler) 1 end]
+    if {[info exists tv]} {
+	if {[string match {.@who*} $tv] && [winfo exists $tv]} { $tv yview 0 }
+	unset tv
     }
 }
 #
 proc irc352 {net prefix param pargs} {
-    global whoTxt
+    upvar #0 $net ndata
+    set pp [lindex $ndata(whohandler) 0]
+    eval $pp $net [list $pargs] [list $param]
+}
+#
+proc doWhoLine {net pargs param} {
+    upvar #0 whoTxt($net) tv
     set fmt "%-9s\t%-14s\t%-3s\t%s@%s (%s)\n" 
     set txt [format $fmt [lindex $pargs 1] \
       [lindex $pargs 5] [lindex $pargs 6] [lindex $pargs 2] \
       [lindex $pargs 3] $param]
-    if {![info exists whoTxt($net)]} {
-	set whoTxt($net) [mkInfoBox $net WHO .@[newName who] "Who [getDate]" {} "dismiss {}"]
-	$whoTxt($net) configure -tabs {1i 2i 3i}
+    if {![info exists tv]} {
+	set tv [mkInfoBox $net WHO .@[newName who] "Who [getDate]" {} "dismiss {}"]
+	$tv configure -tabs {1i 2i 3i}
     }
-    if {![winfo exists $whoTxt($net)]} return
-    $whoTxt($net) configure -state normal
-    insertText [$net info] $whoTxt($net) $txt {}
-    $whoTxt($net) configure -state disabled
-    set ln [lindex [split [$whoTxt($net) index end] .] 0]
-    if {$ln < 24 && $ln > 10} {
-	$whoTxt($net) configure -height $ln
-    }
-    $whoTxt($net) see end
+    if {![winfo exists $tv]} return
+    $tv configure -state normal
+    insertText [$net info] $tv $txt {}
+    $tv configure -state disabled
+    set ln [lindex [split [$tv index end] .] 0]
+    if {$ln < 24 && $ln > 10} { $tv configure -height $ln }
+    $tv see end
 }
 #
 proc irc367 {net prefix param pargs} {
