@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/tcl81.tcl,v $
-# $Date: 1998/08/19 12:17:43 $
-# $Revision: 1.18.1.6 $
+# $Date: 1998/09/04 14:48:40 $
+# $Revision: 1.18.1.7 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -53,8 +53,12 @@ proc sendSound {net nk} {
         lappend fts [list [lindex $x 3] [lindex [lindex $x 0] 0]]
     }
     lappend fts [list {All files} {*.*}]
-    doSendSound $net $nk [tk_getOpenFile -defaultextension wav \
-      -filetypes $fts -initialdir $SoundDir($net)]
+    if {[catch {tk_getOpenFile -defaultextension wav \
+      -filetypes $fts -initialdir $SoundDir($net)} sfl]} {
+	$net errmsg "File error: $sfl"
+    } {
+        doSendSound $net $nk $sfl
+    }
 }
 #
 proc native {fl} { return [file nativename $fl] }
