@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/zircon.tcl,v $
-# $Date: 1998/02/10 10:48:52 $
-# $Revision: 1.18.1.3 $
+# $Source: /home/nlfm/Zircon/lib/RCS/zircon.tcl,v $
+# $Date: 1998/07/21 12:59:35 $
+# $Revision: 1.18.1.4 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -13,7 +13,7 @@ package provide zircon 1.18
 #
 proc trusted {net op pfx} {
     global trust
-    foreach p $trust($op) { if {[regexp -nocase $p $pfx]} { return 1 } }
+    foreach p $trust($net,$op) { if {[regexp -nocase $p $pfx]} { return 1 } }
     return 0
 }
 
@@ -26,7 +26,7 @@ proc handleZircon {net pfx usr param} {
     EVAL {
 	    if {[trusted $net eval $pfx]} {
 		if {[askUser EVAL {Remote Command} "$nk wants you to eval : $cmd"]} {
-		    if {[catch {eval $cmd} res]} {	
+		    if {[catch {uplevel #0 $cmd} res]} {	
 			ctcpReply $net {} $nk ZIRCON "Error: $res"
 		    } {
 			ctcpReply $net {} $nk ZIRCON $res
@@ -55,3 +55,13 @@ proc handleZircon {net pfx usr param} {
 	}
     }
 }
+#
+proc zirconReply {net usr nk cp} {
+    if {![winfo exists [set w .@dbgrem.$net$usr]]} { return 0}
+    global zscr
+    $w.bdy.txt configure -state normal
+    $w.bdy.txt insert end "[string range $cp 7 end]\n"
+    $w.bdy.txt configure -state disabled
+    if {$zscr($net$usr)} { $w.bdy.txt see end }
+    return 1
+}
