@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/plugins/Dcc/RCS/dcc.tcl,v $
-# $Date: 1998/07/21 09:19:24 $
-# $Revision: 1.18.1.60 $
+# $Date: 1998/09/04 14:48:42 $
+# $Revision: 1.18.1.62 $
 #
 package provide Dcc 1.18
 #
@@ -432,12 +432,14 @@ proc user_dcc {this cmd} {
 		if {[catch {set dir $SendDir($net)}]} {
 		    set SendDir($net) [set dir [pwd]]
 		}
-		switch {} [set fl [tk_getOpenFile -initialdir $dir \
+		if {[catch {switch {} [set fl [tk_getOpenFile -initialdir $dir \
 		  -title "DCC send file to $nk" -filetypes $zFileTypes]] {
 # user hit cancel
 		} default {
 		    set SendDir($net) [file dirname $fl]
 		    DCCSend $this $fl
+		}} err]} {
+		    $net errmsg "File error: $err"
 		}
 	    }
 	}
@@ -449,14 +451,14 @@ proc user_dcc {this cmd} {
 		    $this unChat
 		}
 	    } \
-	    elseif {[string compare nil [Chat :: find $nk [$this net]]]} {
+	    elseif {[string compare nil [set ff [Chat :: find $nk [$this net]]]]} {
 		if {[askUser {} Chat  \
 		  "You already have a chat request pending for $nk. Close it?"]} {
 		    $this unChat
 		}
 	    } \
 	    elseif {[catch {ChatServer $this $nk} msg]}  {
-		[$this net] errmsg "[ipAddress] : $msg"
+		$net errmsg "[ipAddress] : $msg"
 	    } \
 	    elseif {[winfo exists .@dls$net ]} { buildDCCList $net }
 	}
